==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ToolActionIconButtonDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
import { ToolActionIconButtonDescription } from "./ToolActionIconButtonDescription";
/**
 * @hidden
 */
export let ToolActionIconButtonDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionIconButtonDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionIconButtonDescriptionMetadata.a == null) {
                ToolActionIconButtonDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionIconButtonDescriptionMetadata.c(ToolActionIconButtonDescriptionMetadata.a);
            }
            if (a.k(ToolActionIconButtonDescriptionMetadata.a)) {
                return;
            }
            a.aa(ToolActionIconButtonDescriptionMetadata.a);
        }
        static c(a) {
            ToolActionDescriptionMetadata.c(a);
        }
        static d(a) {
            ToolActionIconButtonDescriptionMetadata.b(a);
            a.ac("ToolActionIconButton", () => new ToolActionIconButtonDescription());
            a.ab("ToolActionIconButton", ToolActionIconButtonDescriptionMetadata.a);
        }
    }
    ToolActionIconButtonDescriptionMetadata.$t = /*@__PURE__*/ markType(ToolActionIconButtonDescriptionMetadata, 'ToolActionIconButtonDescriptionMetadata');
    ToolActionIconButtonDescriptionMetadata.a = null;
    return ToolActionIconButtonDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/ToolActionIconButtonDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionPopupOpeningEventArgsDescriptionMetadata } from "./ToolActionPopupOpeningEventArgsDescriptionMetadata";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
import { ToolActionIconButtonDescription } from "./ToolActionIconButtonDescription";
/**
 * @hidden
 */
export let ToolActionIconButtonDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionIconButtonDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionIconButtonDescriptionMetadata.a == null) {
                ToolActionIconButtonDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionIconButtonDescriptionMetadata.c(ToolActionIconButtonDescriptionMetadata.a);
            }
            if (a.k(ToolActionIconButtonDescriptionMetadata.a)) {
                return;
            }
            a.ac(ToolActionIconButtonDescriptionMetadata.a);
            ToolActionPopupOpeningEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            ToolActionDescriptionMetadata.c(a);
            a.item("TooltipDelay", "Number:int");
            a.item("ActualTooltipDelay", "Number:int");
            a.item("ContentPaddingLeft", "Number:double");
            a.item("ActualContentPaddingLeft", "Number:double");
            a.item("ContentPaddingTop", "Number:double");
            a.item("ActualContentPaddingTop", "Number:double");
            a.item("ContentPaddingRight", "Number:double");
            a.item("ActualContentPaddingRight", "Number:double");
            a.item("ContentPaddingBottom", "Number:double");
            a.item("ActualContentPaddingBottom", "Number:double");
            a.item("PopupOpeningRef", "EventRef::popupOpening");
        }
        static d(a) {
            ToolActionIconButtonDescriptionMetadata.b(a);
            a.ae("ToolActionIconButton", () => new ToolActionIconButtonDescription());
            a.ad("ToolActionIconButton", ToolActionIconButtonDescriptionMetadata.a);
        }
    }
    ToolActionIconButtonDescriptionMetadata.$t = /*@__PURE__*/ markType(ToolActionIconButtonDescriptionMetadata, 'ToolActionIconButtonDescriptionMetadata');
    ToolActionIconButtonDescriptionMetadata.a = null;
    return ToolActionIconButtonDescriptionMetadata;
})();
